"use strict";(self.webpackChunkcad_viewer_widget=self.webpackChunkcad_viewer_widget||[]).push([[549],{2760:(n,e,a)=>{a.d(e,{Z:()=>d});var r=a(8081),p=a.n(r),i=a(3645),o=a.n(i),t=a(4775),c=o()(p());c.i(t.Z),c.push([n.id,"/* .cvw-sidecar {\n    background: var(--jp-layout-color0);\n    display: flex;\n    flex-direction: row;\n}\n\n.cvw-sidecar > .jp-Toolbar {\n    display: none;\n}\n\n.cvw-sidecar > .p-Widget {\n    top: 0px !important;\n} */\n\n.jupyterlab-sidecar {\n  background: var(--jp-layout-color0);\n  display: flex;\n}\n\n.jupyterlab-sidecar .jp-OutputPrompt.jp-OutputArea-prompt {\n  display: none;\n}\n\n.jupyterlab-sidecar > .jp-OutputArea-child {\n  flex: 1;\n}\n\n.jp-SideBar.jp-mod-right .p-TabBar-tabCloseIcon {\n  padding: 4px 0px 4px 4px;\n  background-size: 16px;\n  height: 16px;\n  width: 16px;\n  background-image: var(--jp-icon-close);\n  background-position: center;\n  background-repeat: no-repeat;\n  align-self: center;\n}\n\n.jp-SideBar.jp-mod-right .p-TabBar-tabCloseIcon:hover {\n  background-size: 16px;\n  background-image: var(--jp-icon-inverse-close-circle);\n}\n",""]);const d=c},7549:(n,e,a)=>{a.r(e),a.d(e,{default:()=>x});var r=a(3379),p=a.n(r),i=a(7795),o=a.n(i),t=a(569),c=a.n(t),d=a(3565),l=a.n(d),s=a(9216),u=a.n(s),b=a(4589),g=a.n(b),j=a(2760),v={};v.styleTagTransform=g(),v.setAttributes=l(),v.insert=c().bind(null,"head"),v.domAPI=o(),v.insertStyleElement=u(),p()(j.Z,v);const x=j.Z&&j.Z.locals?j.Z.locals:void 0}}]);